@@ -53,13 +53,13 @@ import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.List;
 
+import com.openexchange.java.Strings;
 import com.openexchange.mobile.api.facade.auth.SessionData;
 import com.openexchange.mobile.api.facade.connectors.BaseConnector;
 import com.openexchange.mobile.api.facade.connectors.RequestConfiguration;
 import com.openexchange.mobile.api.facade.connectors.responses.ArrayDataResponseMto;
 import com.openexchange.mobile.api.facade.connectors.responses.mtos.AccountMto;
 import com.openexchange.mobile.api.facade.exceptions.ApiFacadeException;
-import com.openexchange.mobile.api.facade.utils.StringUtils;
 
 import org.apache.http.client.methods.HttpUriRequest;
 import org.apache.http.client.methods.RequestBuilder;
@@ -88,7 +88,6 @@ public class AccountsConnector extends BaseConnector<ArrayDataResponseMto> {
     }
 
     public static AccountMto map(Object[][] data, String accountId) {
-        List<AccountMto> accounts = new ArrayList<>(data.length);
         for (int index = 0; index < data.length; index++) {
             if (accountId.equals(data[index][0].toString())) {
                 return map(data[index]);
@@ -114,7 +113,7 @@ public class AccountsConnector extends BaseConnector<ArrayDataResponseMto> {
     }
 
     private static List<String> getAliases(String primaryAddress, String aliasesStr) {
-        if (StringUtils.isEmpty(aliasesStr)) {
+        if (Strings.isEmpty(aliasesStr)) {
             return null;
         }
         String[] splittedAliases = aliasesStr.split(",");
